Struct MessageHash

pub struct MessageHash(pub(crate) [u8; 32]);
A message hash for ECDSA operations. Can be created either via MessageHash::sha256 or MessageHash::keccak256. If you need a different hash function you can hash yourself and construct via MessageHash::from_hash.

Tuple Fields

0: [u8; 32]

Implementations

Source

impl MessageHash

pub fn from_hash(hash: [u8; 32]) -> Self

Creates a new MessageHash from a 32-byte hash.

pub fn as_bytes(&self) -> &[u8; 32]

Returns a reference to the underlying hash byte array.

pub fn into_bytes(self) -> [u8; 32]

Consumes the MessageHash and returns the underlying hash byte array.

pub fn sha256(msg: &[u8]) -> Self

Uses SHA-256 to hash the message and returns a MessageHash.

pub fn keccak256(msg: &[u8]) -> Self

Uses Keccak-256 to hash the message and returns a MessageHash.

fn hash( msg: &[u8], f: unsafe extern "C" fn(*const u8, usize, *mut [u8; 32]), ) -> Self